@@ -7,10 +7,11 @@ import pathlib as p
 import re
 import typing as t
 
-from ...base import Foam, Path
+from ...base.core import Foam
+from ...base.type import Path
 
 if t.TYPE_CHECKING:
-    from ..command import Command
+    from ..command.core import Command
 
 
 class Information:
@@ -31,7 +32,7 @@ class Information:
     @property
     def cmd(self) -> 'Command':
         '''Command without asserting (no need to call `Foam::save` method first)'''
-        from ..command import Command
+        from ..command.core import Command
 
         if self._cmd is None:
             self._cmd = Command.from_foam_without_asserting(self._foam)
@@ -102,14 +103,14 @@ class Information:
             if path.suffix in {'.yaml', '.yml'}:
                 # try-except or try-except-else?
                 try:
-                    foam = Foam.from_file(path)
-                except:  # TODO: catch ConstructorError only
-                    continue
-                for keys, _ in foam['foam'].items(with_list=False):
-                    hashed_keys = tuple(map(hashing, keys))
-                    if hashed_keys[-length:] == hashed_targets:
-                        record[foam['foam'][keys]].add(path.absolute().as_posix())
-                        break
+                    foam = Foam.from_file(path, warn=False)
+                    for keys, _ in foam['foam'].items(with_list=False):
+                        hashed_keys = tuple(map(hashing, keys))
+                        if hashed_keys[-length:] == hashed_targets:
+                            record[foam['foam'][keys]].add(path.absolute().as_posix())
+                            break
+                except:  # TODO: catch specific exceptions only
+                    pass
         return dict(record)
 
     def commands(self, foam_only: bool = True) -> t.Set[str]:
