@@ -3,12 +3,9 @@ __all__ = ['Foam']
 
 import functools as f
 import gc
-import io
 import json
 import os
 import pathlib as p
-import shutil
-import sys
 import typing as t
 import warnings as w
 
@@ -17,7 +14,9 @@ from .parse import Parser
 from .type import Dict, List, Path, Data, Version
 
 if t.TYPE_CHECKING:
-    from ..app import Command, Information, PostProcess
+    from ..app.command.core import Command
+    from ..app.information.core import Information
+    from ..app.postprocess.core import PostProcess
 
 
 class Foam:
@@ -30,28 +29,28 @@ class Foam:
         >>> foam.cmd.all_run()
     '''
 
-    __version__ = '0.11.4'
+    __version__ = '0.11.6'
 
-    parse = Parser.new()
-
-    def __init__(self, data: List, root: Path) -> None:
+    def __init__(self, data: List, root: Path, warn: bool = True) -> None:
         self._list = data
         self._root = p.Path(root)
         self._dest: t.Optional[p.Path] = None
 
+        self._parser: t.Optional[Parser] = None
         self._cmd: t.Optional['Command'] = None
         self._info: t.Optional['Information'] = None
         self._post: t.Optional['PostProcess'] = None
 
-        openfoam = set(map(str, self.meta.get('openfoam', [])))
-        if str(self.environ['WM_PROJECT_VERSION']) not in openfoam:
-            w.warn(f'OpenFOAM version mismatch: {root}')
-        version = self._parse(self.__version__)
-        current = self._parse(str(self.meta.get('version', '0.0.0')))
-        if (version.major, version.minor) < (current.major, current.minor):
-            w.warn('Forward compatibility is not yet guaranteed')
-        elif (version.major, version.minor) > (current.major, current.minor):
-            w.warn('Backward compatibility is not yet guaranteed')
+        if warn:
+            openfoam = set(map(str, self.meta.get('openfoam', [])))
+            if str(self.environ['WM_PROJECT_VERSION']) not in openfoam:
+                w.warn(f'OpenFOAM version mismatch: {root}')
+            version = self._parse(self.__version__)
+            current = self._parse(str(self.meta.get('version', '0.0.0')))
+            if (version.major, version.minor) < (current.major, current.minor):
+                w.warn('Forward compatibility is not yet guaranteed')
+            elif (version.major, version.minor) > (current.major, current.minor):
+                w.warn('Backward compatibility is not yet guaranteed')
 
     def __getitem__(self, key: str) -> t.Optional['Data']:
         try:
@@ -63,7 +62,7 @@ class Foam:
         return f'<Foam @ "{self._root.absolute().as_posix()}">'
 
     @classmethod
-    def from_file(cls, path: Path) -> t.Self:
+    def from_file(cls, path: Path, **kwargs: t.Any) -> t.Self:
         '''Supported format: json, yaml'''
         path = p.Path(path)
         for suffixes, method in [
@@ -71,18 +70,18 @@ class Foam:
             ({'.yaml', '.yml'}, cls.from_yaml),
         ]:
             if path.suffix in suffixes:
-                return method(path.read_text('utf-8'), path.parent)
+                return method(path.read_text('utf-8'), path.parent, **kwargs)
         raise Exception(f'Suffix "{path.suffix}" not supported')
 
     @classmethod
-    def from_json(cls, text: str, root: Path) -> t.Self:
+    def from_json(cls, text: str, root: Path, **kwargs: t.Any) -> t.Self:
         data = json.loads(text)
-        return cls(data, root)
+        return cls(data, root, **kwargs)
 
     @classmethod
-    def from_yaml(cls, text: str, root: Path) -> t.Self:
+    def from_yaml(cls, text: str, root: Path, **kwargs: t.Any) -> t.Self:
         data = list(lib['yaml'].load_all(text, Loader=lib['SafeLoader']))
-        return cls(data, root)
+        return cls(data, root, **kwargs)
 
     @classmethod
     def as_placeholder(cls) -> t.Self:
@@ -93,10 +92,17 @@ class Foam:
         '''Meta information'''
         return self._list[0]
 
+    @property
+    def parser(self) -> Parser:
+        '''All parsers'''
+        if self._parser is None:
+            self._parser = Parser.from_foam(self)
+        return self._parser
+
     @property
     def cmd(self) -> 'Command':
         '''`app.command.Command`'''
-        from ..app import Command
+        from ..app.command.core import Command
 
         if self._cmd is None:
             self._cmd = Command.from_foam(self)
@@ -105,7 +111,7 @@ class Foam:
     @property
     def info(self) -> 'Information':
         '''`app.information.Information`'''
-        from ..app import Information
+        from ..app.information.core import Information
 
         if self._info is None:
             self._info = Information.from_foam(self)
@@ -114,7 +120,7 @@ class Foam:
     @property
     def post(self) -> 'PostProcess':
         '''`app.postprocess.PostProcess`'''
-        from ..app import PostProcess
+        from ..app.postprocess.core import PostProcess
 
         if self._post is None:
             self._post = PostProcess.from_foam(self)
@@ -163,7 +169,7 @@ class Foam:
 
     @f.cached_property
     def ndim(self) -> t.Optional[int]:
-        # TODO: verify that the method is reliable
+        # TODO: verify that this method is reliable
         system = self['foam']['system']
         block_mesh = system.get('blockMeshDict', None)
         if block_mesh is None:
@@ -204,37 +210,9 @@ class Foam:
             path.chmod(int(str(permission), base=8))
 
     def _save_static(self) -> None:
+        # TODO: add to parse sub-module
         for static in self['static'] or []:
-            # TODO: rewritten as match statement when updated to 3.10
-            out = self._path(static['name'])  # self._dest is not None
-            out.parent.mkdir(parents=True, exist_ok=True)
-            if static['type'][0] == 'embed':
-                if static['type'][1] == 'text':
-                    self._write(out, static['data'], static.get('permission', None))
-                elif static['type'][1] == 'binary':
-                    out.write_bytes(static['data'])
-                elif static['type'][1] == '7z':
-                    assert lib['py7zr'] is not None, 'pip install ifoam[7z]'  # TODO: improve error message
-
-                    with lib['py7zr'].SevenZipFile(io.BytesIO(static['data']), mode='r') as z:
-                        z.extractall(path=out.parent)
-            elif static['type'][0] == 'path':
-                in_ = self._root / static['data']
-                if static['type'][1] == 'raw':
-                    if in_.is_dir():
-                        kwargs = {'dirs_exist_ok': True} if sys.version_info >= (3, 8) else {}
-                        shutil.copytree(in_, out, **kwargs)
-                    elif in_.is_file():
-                        shutil.copyfile(in_, out)
-                    else:
-                        raise Exception('Target is neither a file nor a directory')
-                elif static['type'][1] == '7z':
-                    assert lib['py7zr'] is not None, 'pip install ifoam[7z]'  # TODO: improve error message
-
-                    with lib['py7zr'].SevenZipFile(in_, mode='r') as z:
-                        z.extractall(path=out.parent)
-            else:
-                raise Exception(f'Unknown types "{static["type"]}"')
+            self.parser.static[tuple(static['type'])](static)
 
     def _save_foam(self) -> None:
         foam = self['foam']
@@ -250,7 +228,7 @@ class Foam:
             # write the parsed text data
             path = self._path(*map(str, keys))  # self._dest is not None
             path.parent.mkdir(parents=True, exist_ok=True)
-            self._write(path, '\n'.join(self.parse.data(data)))
+            self._write(path, '\n'.join(self.parser.yaml.data(data)))
 
     def _extract_files(
         self,
